@@ -4,12 +4,17 @@
 
 from __future__ import print_function
 from __future__ import unicode_literals
-from collections import namedtuple, Iterable
+from collections import namedtuple
 from platform import python_version_tuple
 import re
 import math
 
 
+if python_version_tuple() >= ("3", "3", "0"):
+    from collections.abc import Iterable
+else:
+    from collections import Iterable
+
 if python_version_tuple()[0] < "3":
     from itertools import izip_longest
     from functools import partial
@@ -47,7 +52,7 @@ except ImportError:
 
 
 __all__ = ["tabulate", "tabulate_formats", "simple_separated_format"]
-__version__ = "0.8.1"
+__version__ = "0.8.4"
 
 
 # minimum extra space in headers
@@ -184,7 +189,7 @@ def _latex_line_begin_tabular(colwidths, colaligns, booktabs=False):
     alignment = { "left": "l", "right": "r", "center": "c", "decimal": "r" }
     tabular_columns_fmt = "".join([alignment.get(a, "l") for a in colaligns])
     return "\n".join(["\\begin{tabular}{" + tabular_columns_fmt + "}",
-                      "\\toprule" if booktabs else "\hline"])
+                      "\\toprule" if booktabs else "\\hline"])
 
 LATEX_ESCAPE_RULES = {r"&": r"\&", r"%": r"\%", r"$": r"\$", r"#": r"\#",
                       r"_": r"\_", r"^": r"\^{}", r"{": r"\{", r"}": r"\}",
@@ -247,6 +252,15 @@ _table_formats = {"simple":
                               headerrow=DataRow("│", "│", "│"),
                               datarow=DataRow("│", "│", "│"),
                               padding=1, with_header_hide=None),
+                  "github":
+                  TableFormat(lineabove=Line("|", "-", "|", "|"),
+                              linebelowheader=Line("|", "-", "|", "|"),
+                              linebetweenrows=None,
+                              linebelow=None,
+                              headerrow=DataRow("|", "|", "|"),
+                              datarow=DataRow("|", "|", "|"),
+                              padding=1,
+                              with_header_hide=["lineabove"]),
                   "pipe":
                   TableFormat(lineabove=_pipe_line_with_colons,
                               linebelowheader=_pipe_line_with_colons,
@@ -756,14 +770,14 @@ def _format(val, valtype, floatfmt, missingval="", has_invisible=True):
         return "{0}".format(val)
 
 
-def _align_header(header, alignment, width, visible_width, is_multiline=False):
+def _align_header(header, alignment, width, visible_width, is_multiline=False, width_fn=None):
     "Pad string header to width chars given known visible_width of the header."
     if is_multiline:
         header_lines = re.split(_multiline_codes, header)
-        padded_lines = [_align_header(h, alignment, width, visible_width) for h in header_lines]
+        padded_lines = [_align_header(h, alignment, width, width_fn(h)) for h in header_lines]
         return "\n".join(padded_lines)
     # else: not multiline
-    ninvisible = max(0, len(header) - visible_width)
+    ninvisible = len(header) - visible_width
     width += ninvisible
     if alignment == "left":
         return _padright(width, header)
@@ -958,7 +972,8 @@ def _normalize_tabular_data(tabular_data, headers, showindex="default"):
 
 def tabulate(tabular_data, headers=(), tablefmt="simple",
              floatfmt=_DEFAULT_FLOATFMT, numalign="decimal", stralign="left",
-             missingval=_DEFAULT_MISSINGVAL, showindex="default", disable_numparse=False):
+             missingval=_DEFAULT_MISSINGVAL, showindex="default", disable_numparse=False,
+             colalign=None):
     """Format a fixed width table for pretty printing.
 
     >>> print(tabulate([[1, 2.34], [-56, "8.999"], ["2", "10001"]]))
@@ -1287,6 +1302,10 @@ def tabulate(tabular_data, headers=(), tablefmt="simple",
 
     # align columns
     aligns = [numalign if ct in [int,float] else stralign for ct in coltypes]
+    if colalign is not None:
+        assert isinstance(colalign, Iterable)
+        for idx, align in enumerate(colalign):
+            aligns[idx] = align
     minwidths = [width_fn(h) + MIN_PADDING for h in headers] if headers else [0]*len(cols)
     cols = [_align_column(c, a, minw, has_invisible, enable_widechars, is_multiline)
             for c, a, minw in zip(cols, aligns, minwidths)]
@@ -1296,7 +1315,7 @@ def tabulate(tabular_data, headers=(), tablefmt="simple",
         t_cols = cols or [['']] * len(headers)
         t_aligns = aligns or [stralign] * len(headers)
         minwidths = [max(minw, max(width_fn(cl) for cl in c)) for minw, c in zip(minwidths, t_cols)]
-        headers = [_align_header(h, a, minw, width_fn(h), is_multiline)
+        headers = [_align_header(h, a, minw, width_fn(h), is_multiline, width_fn)
                    for h, a, minw in zip(headers, t_aligns, minwidths)]
         rows = list(zip(*cols))
     else:
@@ -1461,14 +1480,16 @@ def _main():
     usage = textwrap.dedent(_main.__doc__)
     try:
         opts, args = getopt.getopt(sys.argv[1:],
-                     "h1o:s:F:f:",
-                     ["help", "header", "output", "sep=", "float=", "format="])
+                     "h1o:s:F:A:f:",
+                     ["help", "header", "output", "sep=", "float=", "align=",
+                      "format="])
     except getopt.GetoptError as e:
         print(e)
         print(usage)
         sys.exit(2)
     headers = []
     floatfmt = _DEFAULT_FLOATFMT
+    colalign = None
     tablefmt = "simple"
     sep = r"\s+"
     outfile = "-"
@@ -1479,6 +1500,8 @@ def _main():
             outfile = value
         elif opt in ["-F", "--float"]:
             floatfmt = value
+        elif opt in ["-C", "--colalign"]:
+            colalign = value.split()
         elif opt in ["-f", "--format"]:
             if value not in tabulate_formats:
                 print("%s is not a supported table format" % value)
@@ -1497,17 +1520,20 @@ def _main():
                 f = sys.stdin
             if _is_file(f):
                 _pprint_file(f, headers=headers, tablefmt=tablefmt,
-                             sep=sep, floatfmt=floatfmt, file=out)
+                             sep=sep, floatfmt=floatfmt, file=out,
+                             colalign=colalign)
             else:
                 with open(f) as fobj:
                     _pprint_file(fobj, headers=headers, tablefmt=tablefmt,
-                                 sep=sep, floatfmt=floatfmt, file=out)
+                                 sep=sep, floatfmt=floatfmt, file=out,
+                                 colalign=colalign)
 
 
-def _pprint_file(fobject, headers, tablefmt, sep, floatfmt, file):
+def _pprint_file(fobject, headers, tablefmt, sep, floatfmt, file, colalign):
     rows = fobject.readlines()
     table = [re.split(sep, r.rstrip()) for r in rows if r.strip()]
-    print(tabulate(table, headers, tablefmt, floatfmt=floatfmt), file=file)
+    print(tabulate(table, headers, tablefmt, floatfmt=floatfmt,
+          colalign=colalign), file=file)
 
 
 if __name__ == "__main__":
